Documentation
¶
Index ¶
Constants ¶
const ( LevelInfo = iota LevelWarn LevelError LevelCritical )
Log levels constants
Variables ¶
This section is empty.
Functions ¶
func InitFromEnv ¶
func InitFromEnv()
InitFromEnv sets the log level based on an environment variable
func InitializeGlobalLogger ¶
InitializeGlobalLogger creates and initializes the global logger instance
Types ¶
type Logger ¶
type Logger struct {
// contains filtered or unexported fields
}
Logger struct holds different loggers for various log levels
func GetGlobalLogger ¶
func GetGlobalLogger() *Logger
GetGlobalLogger returns the global logger instance
func (*Logger) MarshalJSON ¶
func (*Logger) UnmarshalJSON ¶
Click to show internal directories.
Click to hide internal directories.